@@ -23,7 +23,7 @@ def unused():
 
     args = parser.parse_args()
 
-    files = glob(path.join(args.dirname), "*.hst")
+    files = glob(path.join(args.dirname, "*.hst"))
     programs = [Histogram.parse(file, isa=args.isa) for file in files]
 
     inst_used = {}
